@@ -779,7 +779,7 @@ class VideoUploader(AsyncEvent):
                 "upcdn": self.line["upcdn"],
                 "probe_version": self.line["probe_version"],
             },
-            cookies=self.credential.get_cookies(),
+            cookies=await self.credential.get_buvid_cookies(),
             headers={
                 "User-Agent": "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_15_7) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/131.0.0.0 Safari/537.36 Edg/131.0.0.0",
                 "Referer": "https://www.bilibili.com",
